@@ -291,6 +291,10 @@ drawlatent3 <- function(y, x, beta, sigma, nu, theta, tau2, gammacp) {
         b <- gammacp[temp + 1]
         z[1, i] <- rtruncnorm(n = 1, a = a, b = b,
                               mean = meanp, sd = std)
+        if(is.na(z[1, i]) == TRUE) {
+            z[1, i] <- rtruncnorm(n = 1, a = -a, b = b,
+                                  mean = meanp, sd = std)
+        }
     }
     return(z)
 }
